==> common-api-0.0.98-sources.jar: io/aether/api/common/SignAE_ED25519.java <==
package io.aether.api.common;
import java.net.URI;
import java.net.URISyntaxException;
import io.aether.net.fastMeta.FastMetaType;
import java.util.UUID;
import java.util.Date;
import io.aether.net.fastMeta.BytesConverter;
import java.io.Closeable;
import io.aether.net.fastMeta.*;
import io.aether.utils.dataio.DataIn;
import io.aether.utils.dataio.DataOut;
import io.aether.utils.dataio.DataInOutStatic;
import io.aether.utils.dataio.DataInOut;
import it.unimi.dsi.fastutil.objects.ObjectSet;
import it.unimi.dsi.fastutil.bytes.ByteSet;
import it.unimi.dsi.fastutil.doubles.DoubleSet;
import it.unimi.dsi.fastutil.floats.FloatSet;
import it.unimi.dsi.fastutil.ints.IntSet;
import it.unimi.dsi.fastutil.longs.LongSet;
import it.unimi.dsi.fastutil.shorts.ShortSet;
import io.aether.utils.interfaces.AConsumer;
import io.aether.utils.futures.AFuture;
import io.aether.utils.futures.ARFuture;
import java.lang.annotation.*;
import static java.lang.annotation.ElementType.*;
import static java.lang.annotation.RetentionPolicy.*;
import java.util.*;
public class SignAE_ED25519 extends Sign implements io.aether.utils.ToString  {
    @Override public int getAetherTypeId() {
        return 1;
        
    }
    public static final FastMetaType<SignAE_ED25519> META_BODY = new FastMetaType<>() {
        @Override public void serialize(FastFutureContext serializeContextVar_136, SignAE_ED25519 obj_137, DataOut out_138) {
            if(obj_137.data.length!=64) throw new java.lang.IllegalArgumentException("Array length is bad for obj_137.data=="+obj_137.data.length+" but must be 64");
            out_138.write(obj_137.data);
            
        }
        @Override public SignAE_ED25519 deserialize(FastFutureContext serializeContextVar_136, DataIn in_139) {
            byte[] data_140;
            var arraySize_141=64;
            data_140=new byte[arraySize_141];
            in_139.read(data_140);
            return new SignAE_ED25519(data_140);
            
        }
        
    };
    public static final FastMetaType<SignAE_ED25519> META = new FastMetaType<>() {
        @Override public void serialize(FastFutureContext serializeContextVar_142, SignAE_ED25519 obj_143, DataOut out_144) {
            SignAE_ED25519.META_BODY.serialize(serializeContextVar_142, obj_143, out_144);
            
        }
        @Override public SignAE_ED25519 deserialize(FastFutureContext serializeContextVar_142, DataIn in_145) {
            return SignAE_ED25519.META_BODY.deserialize(serializeContextVar_142, in_145);
            
        }
        
    };
    protected final @L(64) byte[] data;
    public SignAE_ED25519(@L(64) byte[] data)  {
        if (data == null)  {
            throw new java.lang.NullPointerException("Field 'data' cannot be null.");
            
        }
        if (data.length != 64)  {
            throw new java.lang.IllegalArgumentException("Array length for field 'data' must be 64 but was " + data.length);
            
        }
        this.data = data;
        
    }
    public @L(64) byte[] getData()  {
        return this.data;
        
    }
    public boolean dataContains(byte el)  {
        return ByteSet.of(this.data).contains(el);
        
    }
    @Override public boolean equals(Object o)  {
        if (this == o) return true;
        if (o == null || !(o instanceof SignAE_ED25519)) return false;
        SignAE_ED25519 that = (SignAE_ED25519) o;
        return java.util.Arrays.equals(this.data, that.data);
        
    }
    @Override public int hashCode()  {
        return java.util.Objects.hash(java.util.Arrays.hashCode(this.data));
        
    }
    @Override public void toString(io.aether.utils.AString sb)  {
        sb.add("SignAE_ED25519(");
        sb.add("data:");
        sb.add(this.data);
        sb.add(')');
        
    }
    
}

==> common-api-0.0.100-sources.jar: io/aether/api/common/SignAE_ED25519.java <==
package io.aether.api.common;
import java.net.URI;
import java.net.URISyntaxException;
import io.aether.net.fastMeta.FastMetaType;
import java.util.UUID;
import java.util.Date;
import io.aether.net.fastMeta.BytesConverter;
import java.io.Closeable;
import io.aether.net.fastMeta.*;
import io.aether.utils.dataio.DataIn;
import io.aether.utils.dataio.DataOut;
import io.aether.utils.dataio.DataInOutStatic;
import io.aether.utils.dataio.DataInOut;
import it.unimi.dsi.fastutil.objects.ObjectSet;
import it.unimi.dsi.fastutil.bytes.ByteSet;
import it.unimi.dsi.fastutil.doubles.DoubleSet;
import it.unimi.dsi.fastutil.floats.FloatSet;
import it.unimi.dsi.fastutil.ints.IntSet;
import it.unimi.dsi.fastutil.longs.LongSet;
import it.unimi.dsi.fastutil.shorts.ShortSet;
import io.aether.utils.interfaces.AConsumer;
import io.aether.utils.futures.AFuture;
import io.aether.utils.futures.ARFuture;
import java.lang.annotation.*;
import static java.lang.annotation.ElementType.*;
import static java.lang.annotation.RetentionPolicy.*;
import java.util.*;
public class SignAE_ED25519 extends Sign implements io.aether.utils.ToString  {
    @Override public int getAetherTypeId() {
        return 1;
        
    }
    public static final FastMetaType<SignAE_ED25519> META_BODY = new FastMetaType<>() {
        @Override public void serialize(FastFutureContext serializeContextVar_136, SignAE_ED25519 obj_137, DataOut out_138) {
            if(obj_137.data.length!=64) throw new java.lang.IllegalArgumentException("Array length is bad for obj_137.data=="+obj_137.data.length+" but must be 64");
            out_138.write(obj_137.data);
            
        }
        @Override public SignAE_ED25519 deserialize(FastFutureContext serializeContextVar_136, DataIn in_139) {
            byte[] data_140;
            var arraySize_141=64;
            data_140=new byte[arraySize_141];
            in_139.read(data_140);
            return new SignAE_ED25519(data_140);
            
        }
        
    };
    public static final FastMetaType<SignAE_ED25519> META = new FastMetaType<>() {
        @Override public void serialize(FastFutureContext serializeContextVar_142, SignAE_ED25519 obj_143, DataOut out_144) {
            SignAE_ED25519.META_BODY.serialize(serializeContextVar_142, obj_143, out_144);
            
        }
        @Override public SignAE_ED25519 deserialize(FastFutureContext serializeContextVar_142, DataIn in_145) {
            return SignAE_ED25519.META_BODY.deserialize(serializeContextVar_142, in_145);
            
        }
        
    };
    protected final byte[] data;
    public SignAE_ED25519(byte[] data)  {
        if (data == null)  {
            throw new java.lang.NullPointerException("Field 'data' cannot be null.");
            
        }
        if (data.length != 64)  {
            throw new java.lang.IllegalArgumentException("Array length for field 'data' must be 64 but was " + data.length);
            
        }
        this.data = data;
        
    }
    public byte[] getData()  {
        return this.data;
        
    }
    public boolean dataContains(byte el)  {
        return ByteSet.of(this.data).contains(el);
        
    }
    @Override public boolean equals(Object o)  {
        if (this == o) return true;
        if (o == null || !(o instanceof SignAE_ED25519)) return false;
        SignAE_ED25519 that = (SignAE_ED25519) o;
        return java.util.Arrays.equals(this.data, that.data);
        
    }
    @Override public int hashCode()  {
        return java.util.Objects.hash(java.util.Arrays.hashCode(this.data));
        
    }
    @Override public String toString()  {
        return toString2();
        
    }
    @Override public void toString(io.aether.utils.AString sb)  {
        sb.add("SignAE_ED25519(");
        sb.add("data:");
        sb.add(this.data);
        sb.add(')');
        
    }
    
}
